@@ -1,10 +1,13 @@
 import traceback
 import importlib
+from typing import Union
+from dataclasses import dataclass
 from datetime import datetime, timedelta
 from urllib.parse import urlparse, urlunparse, urljoin
 
 import pytest
 from box import Box
+from faker import Faker
 
 from framework.db.redis_db import RedisDB
 from framework.db.mysql_db import MysqlDB
@@ -13,9 +16,8 @@ from framework.render_data import RenderData
 from framework.http_client import ResponseUtil
 from framework.utils.date_util import DateUtil
 from framework.utils.common import snake_to_pascal, SingletonFaker
-from framework.global_attribute import GlobalAttribute, _FRAMEWORK_CONTEXT,CONTEXT
-from framework.exceptions import ValidateException, RenderException, RequestException, ResponseException, \
-    GetAccountError, GetAppHttpError
+from framework.global_attribute import GlobalAttribute, _FRAMEWORK_CONTEXT, CONTEXT
+from framework.exceptions import ValidateException, RenderException, RequestException, GetAccountError, GetAppHttpError
 from framework.utils.mock_util import get_customized_kytmock, set_customized_kytmock, PaymentType, RiskLevel, IsDelayed
 
 from handlers.extend_base_test_case_attr import ExtendBaseTestCase
@@ -24,22 +26,31 @@ from config.settings import UNAUTHORIZED_CODE, FAKER_LANGUAGE
 module = importlib.import_module("test_case.conftest")
 
 
+@dataclass
+class Scenario:
+    describe: str
+    level: str
+    data: Box
+    expect: Box
+
+
 class BaseTestCase(ExtendBaseTestCase):
     http = None
     data: Box = None
-    scenario: Box = None
     belong_app = None
+    scenario: Scenario = None
     response: ResponseUtil = None
-    context: GlobalAttribute = None
-    config: GlobalAttribute = None
+    context: Union[GlobalAttribute, Box] = None
+    config: Union[GlobalAttribute, Box] = None
+    # faker方法文档 https://blog.csdn.net/m0_60052979/article/details/126368024
+    faker: Faker = SingletonFaker(locale=FAKER_LANGUAGE).faker
+    env = CONTEXT.get("env")
+    logger: logger = logger
+
+    date_util: DateUtil = DateUtil
     payment_type: PaymentType = PaymentType
     risk_level: RiskLevel = RiskLevel
     is_delayed: IsDelayed = IsDelayed
-    date_util: DateUtil = DateUtil
-    logger: logger = logger
-    # faker方法文档 https://blog.csdn.net/m0_60052979/article/details/126368024
-    faker = SingletonFaker(locale=FAKER_LANGUAGE).faker
-    env = CONTEXT.get("env")
 
     def request(self, app=None, *, account, data, **kwargs) -> ResponseUtil:
         try:
@@ -83,11 +94,6 @@ class BaseTestCase(ExtendBaseTestCase):
             traceback.print_exc()
             pytest.fail(str(e))
 
-        except ResponseException as e:
-            logger.error(f"响应异常: {e}")
-            traceback.print_exc()
-            pytest.fail(str(e))
-
         except ValidateException as e:
             logger.error(f"断言异常: {e}")
             traceback.print_exc()
