@@ -614,6 +614,8 @@ def sort(case_items):
 def pytest_collection_finish(session):
     """获取最终排序后的 items 列表"""
     logger.info(f"共收集到 {len(session.items)} 个测试用例")
+    if not session.items:
+        pytest.exit("未收集到用例")
     # 过滤掉item名称是test_setup或test_teardown的
     session.items = [item for item in session.items if item.name not in ["test_setup", "test_teardown"]]
 
